@@ -1,4 +1,4 @@
-# Copyright 2021 - 2024 Universität Tübingen, DKFZ, EMBL, and Universität zu Köln
+# Copyright 2021 - 2025 Universität Tübingen, DKFZ, EMBL, and Universität zu Köln
 # for the German Human Genome-Phenome Archive (GHGA)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -45,5 +45,5 @@ async def run_api() -> None:
     """Run the combined loader and query API."""
     config = Config()  # type: ignore
     configure_logging(config=config)
-    app = await get_app(config=config)
-    await run_server(app=app, config=config)
+    async with get_app(config=config) as app:
+        await run_server(app=app, config=config)
